# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/rating/rating_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/rating/rating_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.rating import rating_pb2 as eolymp_dot_rating_dot_rating__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/rating/rating_service.proto\x12\reolymp.rating\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1a\x65olymp/rating/rating.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"7\n\x0eSetRatingInput\x12%\n\x06rating\x18\x01 \x01(\x0b\x32\x15.eolymp.rating.Rating\"$\n\x0fSetRatingOutput\x12\x11\n\trating_id\x18\x01 \x01(\t\"M\n\x11UpdateRatingInput\x12\x11\n\trating_id\x18\x01 \x01(\t\x12%\n\x06rating\x18\x02 \x01(\x0b\x32\x15.eolymp.rating.Rating\"\x14\n\x12UpdateRatingOutput\"M\n\x11\x44\x65leteRatingInput\x12\x11\n\trating_id\x18\x01 \x01(\t\x12%\n\x06rating\x18\x02 \x01(\x0b\x32\x15.eolymp.rating.Rating\"\x14\n\x12\x44\x65leteRatingOutput\"(\n\x13\x44\x65scribeRatingInput\x12\x11\n\trating_id\x18\x01 \x01(\t\"=\n\x14\x44\x65scribeRatingOutput\x12%\n\x06rating\x18\x01 \x01(\x0b\x32\x15.eolymp.rating.Rating\"\xac\x03\n\x0fListRatingInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.rating.ListRatingInput.Filter\x12\x35\n\x04sort\x18\x32 \x01(\x0e\x32\'.eolymp.rating.ListRatingInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xa2\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\ncontest_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x38\n\ttimestamp\x18\x03 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\"\x19\n\x08Sortable\x12\r\n\tTIMESTAMP\x10\x00\"G\n\x10ListRatingOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.rating.Rating\"\x1f\n\x1d\x44\x65scribeRatingBoundariesInput\"\x99\x01\n\x1e\x44\x65scribeRatingBoundariesOutput\x12\x43\n\x06levels\x18\x01 \x03(\x0b\x32\x33.eolymp.rating.DescribeRatingBoundariesOutput.Level\x1a\x32\n\x05Level\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0e\n\x06rating\x18\x02 \x01(\x05\x12\r\n\x05\x63ount\x18\x03 \x01(\r\"!\n\x1f\x44\x65scribeRatingDistributionInput\"\xac\x01\n DescribeRatingDistributionOutput\x12G\n\x07\x62uckets\x18\x01 \x03(\x0b\x32\x36.eolymp.rating.DescribeRatingDistributionOutput.Bucket\x1a?\n\x06\x42ucket\x12\x12\n\nmin_rating\x18\x01 \x01(\x05\x12\x12\n\nmax_rating\x18\x02 \x01(\x05\x12\r\n\x05\x63ount\x18\x03 \x01(\r2\xf2\x08\n\rRatingService\x12\x88\x01\n\tSetRating\x12\x1d.eolymp.rating.SetRatingInput\x1a\x1e.eolymp.rating.SetRatingOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\t\"\x07/rating\x12\x9d\x01\n\x0cUpdateRating\x12 .eolymp.rating.UpdateRatingInput\x1a!.eolymp.rating.UpdateRatingOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\x15\x1a\x13/rating/{rating_id}\x12\x9d\x01\n\x0c\x44\x65leteRating\x12 .eolymp.rating.DeleteRatingInput\x1a!.eolymp.rating.DeleteRatingOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\x15*\x13/rating/{rating_id}\x12\xa2\x01\n\x0e\x44\x65scribeRating\x12\".eolymp.rating.DescribeRatingInput\x1a#.eolymp.rating.DescribeRatingOutput\"G\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\x15\x12\x13/rating/{rating_id}\x12\x9e\x01\n\nListRating\x12\x1e.eolymp.rating.ListRatingInput\x1a\x1f.eolymp.rating.ListRatingOutput\"O\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\x1d\x12\x1b/members/{member_id}/rating\x12\xa2\x01\n\x18\x44\x65scribeRatingBoundaries\x12,.eolymp.rating.DescribeRatingBoundariesInput\x1a-.eolymp.rating.DescribeRatingBoundariesOutput\")\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x14\x12\x12/rating-boundaries\x12\xaa\x01\n\x1a\x44\x65scribeRatingDistribution\x12..eolymp.rating.DescribeRatingDistributionInput\x1a/.eolymp.rating.DescribeRatingDistributionOutput\"+\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x16\x12\x14/rating-distributionB/Z-github.com/eolymp/go-sdk/eolymp/rating;ratingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.rating.rating_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/rating;rating'
  _globals['_RATINGSERVICE'].methods_by_name['SetRating']._loaded_options = None
  _globals['_RATINGSERVICE'].methods_by_name['SetRating']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\t\"\007/rating'
  _globals['_RATINGSERVICE'].methods_by_name['UpdateRating']._loaded_options = None
  _globals['_RATINGSERVICE'].methods_by_name['UpdateRating']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\025\032\023/rating/{rating_id}'
  _globals['_RATINGSERVICE'].methods_by_name['DeleteRating']._loaded_options = None
  _globals['_RATINGSERVICE'].methods_by_name['DeleteRating']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\025*\023/rating/{rating_id}'
  _globals['_RATINGSERVICE'].methods_by_name['DescribeRating']._loaded_options = None
  _globals['_RATINGSERVICE'].methods_by_name['DescribeRating']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\025\022\023/rating/{rating_id}'
  _globals['_RATINGSERVICE'].methods_by_name['ListRating']._loaded_options = None
  _globals['_RATINGSERVICE'].methods_by_name['ListRating']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\035\022\033/members/{member_id}/rating'
  _globals['_RATINGSERVICE'].methods_by_name['DescribeRatingBoundaries']._loaded_options = None
  _globals['_RATINGSERVICE'].methods_by_name['DescribeRatingBoundaries']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\024\022\022/rating-boundaries'
  _globals['_RATINGSERVICE'].methods_by_name['DescribeRatingDistribution']._loaded_options = None
  _globals['_RATINGSERVICE'].methods_by_name['DescribeRatingDistribution']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\026\022\024/rating-distribution'
  _globals['_SETRATINGINPUT']._serialized_start=249
  _globals['_SETRATINGINPUT']._serialized_end=304
  _globals['_SETRATINGOUTPUT']._serialized_start=306
  _globals['_SETRATINGOUTPUT']._serialized_end=342
  _globals['_UPDATERATINGINPUT']._serialized_start=344
  _globals['_UPDATERATINGINPUT']._serialized_end=421
  _globals['_UPDATERATINGOUTPUT']._serialized_start=423
  _globals['_UPDATERATINGOUTPUT']._serialized_end=443
  _globals['_DELETERATINGINPUT']._serialized_start=445
  _globals['_DELETERATINGINPUT']._serialized_end=522
  _globals['_DELETERATINGOUTPUT']._serialized_start=524
  _globals['_DELETERATINGOUTPUT']._serialized_end=544
  _globals['_DESCRIBERATINGINPUT']._serialized_start=546
  _globals['_DESCRIBERATINGINPUT']._serialized_end=586
  _globals['_DESCRIBERATINGOUTPUT']._serialized_start=588
  _globals['_DESCRIBERATINGOUTPUT']._serialized_end=649
  _globals['_LISTRATINGINPUT']._serialized_start=652
  _globals['_LISTRATINGINPUT']._serialized_end=1080
  _globals['_LISTRATINGINPUT_FILTER']._serialized_start=891
  _globals['_LISTRATINGINPUT_FILTER']._serialized_end=1053
  _globals['_LISTRATINGINPUT_SORTABLE']._serialized_start=1055
  _globals['_LISTRATINGINPUT_SORTABLE']._serialized_end=1080
  _globals['_LISTRATINGOUTPUT']._serialized_start=1082
  _globals['_LISTRATINGOUTPUT']._serialized_end=1153
  _globals['_DESCRIBERATINGBOUNDARIESINPUT']._serialized_start=1155
  _globals['_DESCRIBERATINGBOUNDARIESINPUT']._serialized_end=1186
  _globals['_DESCRIBERATINGBOUNDARIESOUTPUT']._serialized_start=1189
  _globals['_DESCRIBERATINGBOUNDARIESOUTPUT']._serialized_end=1342
  _globals['_DESCRIBERATINGBOUNDARIESOUTPUT_LEVEL']._serialized_start=1292
  _globals['_DESCRIBERATINGBOUNDARIESOUTPUT_LEVEL']._serialized_end=1342
  _globals['_DESCRIBERATINGDISTRIBUTIONINPUT']._serialized_start=1344
  _globals['_DESCRIBERATINGDISTRIBUTIONINPUT']._serialized_end=1377
  _globals['_DESCRIBERATINGDISTRIBUTIONOUTPUT']._serialized_start=1380
  _globals['_DESCRIBERATINGDISTRIBUTIONOUTPUT']._serialized_end=1552
  _globals['_DESCRIBERATINGDISTRIBUTIONOUTPUT_BUCKET']._serialized_start=1489
  _globals['_DESCRIBERATINGDISTRIBUTIONOUTPUT_BUCKET']._serialized_end=1552
  _globals['_RATINGSERVICE']._serialized_start=1555
  _globals['_RATINGSERVICE']._serialized_end=2693
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/ranker/scoreboard.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/ranker/scoreboard.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ranker import format_pb2 as eolymp_dot_ranker_dot_format__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/ranker/scoreboard.proto\x12\reolymp.ranker\x1a\x1a\x65olymp/ranker/format.proto\x1a eolymp/wellknown/direction.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9a\x0b\n\nScoreboard\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nhistorical\x18\x07 \x01(\x08\x12\x0e\n\x06\x66rozen\x18\x14 \x01(\x08\x12-\n\tfreeze_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tfreeze_in\x18\x16 \x01(\r\x12/\n\x0bunfreeze_at\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bunfreeze_in\x18\x18 \x01(\r\x12\x1b\n\x13\x64\x65\x66\x61ult_sort_column\x18( \x01(\t\x12\x37\n\x12\x64\x65\x66\x61ult_sort_order\x18) \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12%\n\x06\x66ormat\x18\n \x01(\x0e\x32\x15.eolymp.ranker.Format\x1a\xb5\x03\n\x03Row\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tmember_id\x18\x03 \x01(\t\x12\r\n\x05score\x18\n \x01(\x02\x12\x0f\n\x07penalty\x18\x0b \x01(\x02\x12\r\n\x05ghost\x18( \x01(\x08\x12\x12\n\nunofficial\x18) \x01(\x08\x12\x0c\n\x04rank\x18\x1e \x01(\r\x12\x12\n\nrank_lower\x18\x1f \x01(\r\x12\x33\n\x06values\x18\x14 \x03(\x0b\x32#.eolymp.ranker.Scoreboard.Row.Value\x1a\xe6\x01\n\x05Value\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tcolumn_id\x18\x02 \x01(\t\x12\x13\n\x0bvalid_after\x18\x1f \x01(\r\x12\x13\n\x0bvalid_until\x18  \x01(\r\x12\r\n\x05score\x18\n \x01(\x02\x12\x0f\n\x07penalty\x18\x0b \x01(\x02\x12\x12\n\npercentage\x18\x0c \x01(\x02\x12\x10\n\x08\x61ttempts\x18\r \x01(\r\x12\x11\n\tsolved_in\x18\x0e \x01(\r\x12\x0f\n\x07upsolve\x18( \x01(\x08\x12\x14\n\x0cvalue_string\x18\x14 \x01(\t\x12\x14\n\x0cvalue_number\x18\x15 \x01(\x05\x1a\x98\x03\n\x06\x43olumn\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x12\n\nshort_name\x18\x05 \x01(\t\x12\x33\n\x04type\x18\x06 \x01(\x0e\x32%.eolymp.ranker.Scoreboard.Column.Type\x12\r\n\x05index\x18\x07 \x01(\r\x12\x0f\n\x07visible\x18\x08 \x01(\x08\x12\x12\n\nfilterable\x18\t \x01(\x08\x12\x10\n\x08sortable\x18\n \x01(\x08\x12\x18\n\x10judge_contest_id\x18\x14 \x01(\t\x12\x18\n\x10judge_problem_id\x18\x15 \x01(\t\x12\x1f\n\x17\x63ommunity_attribute_key\x18\x16 \x01(\t\x12 \n\x18\x63ommunity_attribute_type\x18\x17 \x01(\t\"N\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x43ONTEST\x10\x01\x12\x0b\n\x07PROBLEM\x10\x02\x12\r\n\tATTRIBUTE\x10\x03\x12\x08\n\x04NAME\x10\x04\x12\t\n\x05TOTAL\x10\x05\x1a\xa5\x01\n\x06\x41\x63tion\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\nexecute_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x04type\x18\x03 \x01(\x0e\x32%.eolymp.ranker.Scoreboard.Action.Type\"*\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x46REEZE\x10\x01\x12\x0c\n\x08UNFREEZE\x10\x02\"A\n\x0c\x46\x65tchingMode\x12\n\n\x06LATEST\x10\x00\x12\x0c\n\x08PUNCTUAL\x10\x01\x12\n\n\x06\x46ROZEN\x10\x02\x12\x0b\n\x07UPSOLVE\x10\x03\x42/Z-github.com/eolymp/go-sdk/eolymp/ranker;rankerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ranker.scoreboard_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/ranker;ranker'
  _globals['_SCOREBOARD']._serialized_start=145
  _globals['_SCOREBOARD']._serialized_end=1579
  _globals['_SCOREBOARD_ROW']._serialized_start=496
  _globals['_SCOREBOARD_ROW']._serialized_end=933
  _globals['_SCOREBOARD_ROW_VALUE']._serialized_start=703
  _globals['_SCOREBOARD_ROW_VALUE']._serialized_end=933
  _globals['_SCOREBOARD_COLUMN']._serialized_start=936
  _globals['_SCOREBOARD_COLUMN']._serialized_end=1344
  _globals['_SCOREBOARD_COLUMN_TYPE']._serialized_start=1266
  _globals['_SCOREBOARD_COLUMN_TYPE']._serialized_end=1344
  _globals['_SCOREBOARD_ACTION']._serialized_start=1347
  _globals['_SCOREBOARD_ACTION']._serialized_end=1512
  _globals['_SCOREBOARD_ACTION_TYPE']._serialized_start=1470
  _globals['_SCOREBOARD_ACTION_TYPE']._serialized_end=1512
  _globals['_SCOREBOARD_FETCHINGMODE']._serialized_start=1514
  _globals['_SCOREBOARD_FETCHINGMODE']._serialized_end=1579
# @@protoc_insertion_point(module_scope)



from eolymp.executor import script_pb2 as _script_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenerationTask(_message.Message):
    __slots__ = ("task_id", "reference", "origin", "metadata", "run_count", "interactive_followup", "interactor", "validator", "scripts", "runs")
    class Generator(_message.Message):
        __slots__ = ("script_name", "arguments")
        SCRIPT_NAME_FIELD_NUMBER: _ClassVar[int]
        ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
        script_name: str
        arguments: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, script_name: _Optional[str] = ..., arguments: _Optional[_Iterable[str]] = ...) -> None: ...
    class Run(_message.Message):
        __slots__ = ("reference", "index", "group", "cost", "env", "input_url", "input_content", "input_generator", "answer_url", "answer_content", "answer_generator")
        class EnvEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        REFERENCE_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        GROUP_FIELD_NUMBER: _ClassVar[int]
        COST_FIELD_NUMBER: _ClassVar[int]
        ENV_FIELD_NUMBER: _ClassVar[int]
        INPUT_URL_FIELD_NUMBER: _ClassVar[int]
        INPUT_CONTENT_FIELD_NUMBER: _ClassVar[int]
        INPUT_GENERATOR_FIELD_NUMBER: _ClassVar[int]
        ANSWER_URL_FIELD_NUMBER: _ClassVar[int]
        ANSWER_CONTENT_FIELD_NUMBER: _ClassVar[int]
        ANSWER_GENERATOR_FIELD_NUMBER: _ClassVar[int]
        reference: str
        index: int
        group: int
        cost: float
        env: _containers.ScalarMap[str, str]
        input_url: str
        input_content: str
        input_generator: GenerationTask.Generator
        answer_url: str
        answer_content: str
        answer_generator: GenerationTask.Generator
        def __init__(self, reference: _Optional[str] = ..., index: _Optional[int] = ..., group: _Optional[int] = ..., cost: _Optional[float] = ..., env: _Optional[_Mapping[str, str]] = ..., input_url: _Optional[str] = ..., input_content: _Optional[str] = ..., input_generator: _Optional[_Union[GenerationTask.Generator, _Mapping]] = ..., answer_url: _Optional[str] = ..., answer_content: _Optional[str] = ..., answer_generator: _Optional[_Union[GenerationTask.Generator, _Mapping]] = ...) -> None: ...
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    RUN_COUNT_FIELD_NUMBER: _ClassVar[int]
    INTERACTIVE_FOLLOWUP_FIELD_NUMBER: _ClassVar[int]
    INTERACTOR_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    SCRIPTS_FIELD_NUMBER: _ClassVar[int]
    RUNS_FIELD_NUMBER: _ClassVar[int]
    task_id: str
    reference: str
    origin: str
    metadata: _containers.ScalarMap[str, str]
    run_count: int
    interactive_followup: bool
    interactor: _script_pb2.Script
    validator: _script_pb2.Script
    scripts: _containers.RepeatedCompositeFieldContainer[_script_pb2.Script]
    runs: _containers.RepeatedCompositeFieldContainer[GenerationTask.Run]
    def __init__(self, task_id: _Optional[str] = ..., reference: _Optional[str] = ..., origin: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ..., run_count: _Optional[int] = ..., interactive_followup: bool = ..., interactor: _Optional[_Union[_script_pb2.Script, _Mapping]] = ..., validator: _Optional[_Union[_script_pb2.Script, _Mapping]] = ..., scripts: _Optional[_Iterable[_Union[_script_pb2.Script, _Mapping]]] = ..., runs: _Optional[_Iterable[_Union[GenerationTask.Run, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/auth/oauth2_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/auth/oauth2_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.auth import claims_pb2 as eolymp_dot_auth_dot_claims__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/auth/oauth2_service.proto\x12\x0b\x65olymp.auth\x1a\"eolymp/annotations/ratelimit.proto\x1a\x18\x65olymp/auth/claims.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdf\x02\n\x0fIssueTokenInput\x12:\n\ngrant_type\x18\x01 \x01(\x0e\x32&.eolymp.auth.IssueTokenInput.GrantType\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\x12\x15\n\rclient_secret\x18\x05 \x01(\t\x12\x0c\n\x04\x63ode\x18\x06 \x01(\t\x12\x15\n\rcode_verifier\x18\x07 \x01(\t\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x15\n\rrefresh_token\x18\t \x01(\t\x12\x14\n\x0credirect_uri\x18\n \x01(\t\"a\n\tGrantType\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08PASSWORD\x10\x01\x12\x16\n\x12\x41UTHORIZATION_CODE\x10\x02\x12\x11\n\rREFRESH_TOKEN\x10\x03\x12\x11\n\rEOLYMP_SIGNIN\x10\x04\"\xad\x01\n\x10IssueTokenOutput\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x12\n\ntoken_type\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\r\x12\x15\n\rrefresh_token\x18\x04 \x01(\t\x12\r\n\x05scope\x18\x05 \x01(\t\x12#\n\x06\x63laims\x18\n \x01(\x0b\x32\x13.eolymp.auth.Claims\x12\x10\n\x08id_token\x18\x64 \x01(\t\"%\n\x14IntrospectTokenInput\x12\r\n\x05token\x18\x01 \x01(\t\"\x87\x01\n\x15IntrospectTokenOutput\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12\r\n\x05scope\x18\x02 \x01(\t\x12*\n\x06\x65xpire\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12#\n\x06\x63laims\x18\n \x01(\x0b\x32\x13.eolymp.auth.Claims\"!\n\x10RevokeTokenInput\x12\r\n\x05token\x18\x01 \x01(\t\"\x13\n\x11RevokeTokenOutput\"\xa7\x01\n\x10RequestAuthInput\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63ode_challenge\x18\x02 \x01(\t\x12\x1d\n\x15\x63ode_challenge_method\x18\x03 \x01(\t\x12\x14\n\x0credirect_uri\x18\x04 \x01(\t\x12\x15\n\rresponse_type\x18\x05 \x01(\t\x12\r\n\x05scope\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\"E\n\x11RequestAuthOutput\x12\x1a\n\x12\x61uthorization_code\x18\x01 \x01(\t\x12\x14\n\x0credirect_uri\x18\x02 \x01(\t\"\x0f\n\rUserInfoInput\"5\n\x0eUserInfoOutput\x12#\n\x06\x63laims\x18\n \x01(\x0b\x32\x13.eolymp.auth.Claims2\xef\x03\n\rOAuth2Service\x12[\n\nIssueToken\x12\x1c.eolymp.auth.IssueTokenInput\x1a\x1d.eolymp.auth.IssueTokenOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xf0\x41\xf8\xe2\n\xac\x02\x12j\n\x0fIntrospectToken\x12!.eolymp.auth.IntrospectTokenInput\x1a\".eolymp.auth.IntrospectTokenOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xf0\x41\xf8\xe2\n\xac\x02\x12^\n\x0bRevokeToken\x12\x1d.eolymp.auth.RevokeTokenInput\x1a\x1e.eolymp.auth.RevokeTokenOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xf0\x41\xf8\xe2\n\xac\x02\x12^\n\x0bRequestAuth\x12\x1d.eolymp.auth.RequestAuthInput\x1a\x1e.eolymp.auth.RequestAuthOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xf0\x41\xf8\xe2\n\xac\x02\x12U\n\x08UserInfo\x12\x1a.eolymp.auth.UserInfoInput\x1a\x1b.eolymp.auth.UserInfoOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xf0\x41\xf8\xe2\n\xac\x02\x42+Z)github.com/eolymp/go-sdk/eolymp/auth;authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.auth.oauth2_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/auth;auth'
  _globals['_OAUTH2SERVICE'].methods_by_name['IssueToken']._loaded_options = None
  _globals['_OAUTH2SERVICE'].methods_by_name['IssueToken']._serialized_options = b'\352\342\n\014\365\342\n\000\000\360A\370\342\n\254\002'
  _globals['_OAUTH2SERVICE'].methods_by_name['IntrospectToken']._loaded_options = None
  _globals['_OAUTH2SERVICE'].methods_by_name['IntrospectToken']._serialized_options = b'\352\342\n\014\365\342\n\000\000\360A\370\342\n\254\002'
  _globals['_OAUTH2SERVICE'].methods_by_name['RevokeToken']._loaded_options = None
  _globals['_OAUTH2SERVICE'].methods_by_name['RevokeToken']._serialized_options = b'\352\342\n\014\365\342\n\000\000\360A\370\342\n\254\002'
  _globals['_OAUTH2SERVICE'].methods_by_name['RequestAuth']._loaded_options = None
  _globals['_OAUTH2SERVICE'].methods_by_name['RequestAuth']._serialized_options = b'\352\342\n\014\365\342\n\000\000\360A\370\342\n\254\002'
  _globals['_OAUTH2SERVICE'].methods_by_name['UserInfo']._loaded_options = None
  _globals['_OAUTH2SERVICE'].methods_by_name['UserInfo']._serialized_options = b'\352\342\n\014\365\342\n\000\000\360A\370\342\n\254\002'
  _globals['_ISSUETOKENINPUT']._serialized_start=145
  _globals['_ISSUETOKENINPUT']._serialized_end=496
  _globals['_ISSUETOKENINPUT_GRANTTYPE']._serialized_start=399
  _globals['_ISSUETOKENINPUT_GRANTTYPE']._serialized_end=496
  _globals['_ISSUETOKENOUTPUT']._serialized_start=499
  _globals['_ISSUETOKENOUTPUT']._serialized_end=672
  _globals['_INTROSPECTTOKENINPUT']._serialized_start=674
  _globals['_INTROSPECTTOKENINPUT']._serialized_end=711
  _globals['_INTROSPECTTOKENOUTPUT']._serialized_start=714
  _globals['_INTROSPECTTOKENOUTPUT']._serialized_end=849
  _globals['_REVOKETOKENINPUT']._serialized_start=851
  _globals['_REVOKETOKENINPUT']._serialized_end=884
  _globals['_REVOKETOKENOUTPUT']._serialized_start=886
  _globals['_REVOKETOKENOUTPUT']._serialized_end=905
  _globals['_REQUESTAUTHINPUT']._serialized_start=908
  _globals['_REQUESTAUTHINPUT']._serialized_end=1075
  _globals['_REQUESTAUTHOUTPUT']._serialized_start=1077
  _globals['_REQUESTAUTHOUTPUT']._serialized_end=1146
  _globals['_USERINFOINPUT']._serialized_start=1148
  _globals['_USERINFOINPUT']._serialized_end=1163
  _globals['_USERINFOOUTPUT']._serialized_start=1165
  _globals['_USERINFOOUTPUT']._serialized_end=1218
  _globals['_OAUTH2SERVICE']._serialized_start=1221
  _globals['_OAUTH2SERVICE']._serialized_end=1716
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Attribute(_message.Message):
    __slots__ = ("id", "key", "label", "help", "type", "index", "required", "readonly", "hidden", "visibility", "regexp", "min", "max", "choices", "country", "constraints")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PATCH_ALL: _ClassVar[Attribute.Patch]
        PATCH_LABEL: _ClassVar[Attribute.Patch]
        PATCH_HELP: _ClassVar[Attribute.Patch]
        PATCH_TYPE: _ClassVar[Attribute.Patch]
        PATCH_INDEX: _ClassVar[Attribute.Patch]
        PATCH_REQUIRED: _ClassVar[Attribute.Patch]
        PATCH_READONLY: _ClassVar[Attribute.Patch]
        PATCH_VISIBILITY: _ClassVar[Attribute.Patch]
        PATCH_REGEXP: _ClassVar[Attribute.Patch]
        PATCH_MIN: _ClassVar[Attribute.Patch]
        PATCH_MAX: _ClassVar[Attribute.Patch]
        PATCH_CHOICES: _ClassVar[Attribute.Patch]
        PATCH_CONSTRAINTS: _ClassVar[Attribute.Patch]
    PATCH_ALL: Attribute.Patch
    PATCH_LABEL: Attribute.Patch
    PATCH_HELP: Attribute.Patch
    PATCH_TYPE: Attribute.Patch
    PATCH_INDEX: Attribute.Patch
    PATCH_REQUIRED: Attribute.Patch
    PATCH_READONLY: Attribute.Patch
    PATCH_VISIBILITY: Attribute.Patch
    PATCH_REGEXP: Attribute.Patch
    PATCH_MIN: Attribute.Patch
    PATCH_MAX: Attribute.Patch
    PATCH_CHOICES: Attribute.Patch
    PATCH_CONSTRAINTS: Attribute.Patch
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_TYPE: _ClassVar[Attribute.Type]
        STRING: _ClassVar[Attribute.Type]
        TEXT: _ClassVar[Attribute.Type]
        NUMBER: _ClassVar[Attribute.Type]
        CHOICE: _ClassVar[Attribute.Type]
        DATE: _ClassVar[Attribute.Type]
        EMAIL: _ClassVar[Attribute.Type]
        CHECKBOX: _ClassVar[Attribute.Type]
        COUNTRY: _ClassVar[Attribute.Type]
        REGION: _ClassVar[Attribute.Type]
        INSTITUTION: _ClassVar[Attribute.Type]
        IMAGE: _ClassVar[Attribute.Type]
        FILE: _ClassVar[Attribute.Type]
    UNKNOWN_TYPE: Attribute.Type
    STRING: Attribute.Type
    TEXT: Attribute.Type
    NUMBER: Attribute.Type
    CHOICE: Attribute.Type
    DATE: Attribute.Type
    EMAIL: Attribute.Type
    CHECKBOX: Attribute.Type
    COUNTRY: Attribute.Type
    REGION: Attribute.Type
    INSTITUTION: Attribute.Type
    IMAGE: Attribute.Type
    FILE: Attribute.Type
    class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_VISIBILITY: _ClassVar[Attribute.Visibility]
        PRIVATE: _ClassVar[Attribute.Visibility]
        PUBLIC: _ClassVar[Attribute.Visibility]
        INTERNAL: _ClassVar[Attribute.Visibility]
    UNKNOWN_VISIBILITY: Attribute.Visibility
    PRIVATE: Attribute.Visibility
    PUBLIC: Attribute.Visibility
    INTERNAL: Attribute.Visibility
    class Description(_message.Message):
        __slots__ = ("locale", "label", "help", "choices")
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        LABEL_FIELD_NUMBER: _ClassVar[int]
        HELP_FIELD_NUMBER: _ClassVar[int]
        CHOICES_FIELD_NUMBER: _ClassVar[int]
        locale: str
        label: str
        help: str
        choices: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, locale: _Optional[str] = ..., label: _Optional[str] = ..., help: _Optional[str] = ..., choices: _Optional[_Iterable[str]] = ...) -> None: ...
    class Value(_message.Message):
        __slots__ = ("attribute_key", "attribute_type", "string", "number")
        ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
        ATTRIBUTE_TYPE_FIELD_NUMBER: _ClassVar[int]
        STRING_FIELD_NUMBER: _ClassVar[int]
        NUMBER_FIELD_NUMBER: _ClassVar[int]
        attribute_key: str
        attribute_type: Attribute.Type
        string: str
        number: int
        def __init__(self, attribute_key: _Optional[str] = ..., attribute_type: _Optional[_Union[Attribute.Type, str]] = ..., string: _Optional[str] = ..., number: _Optional[int] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    HELP_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_FIELD_NUMBER: _ClassVar[int]
    READONLY_FIELD_NUMBER: _ClassVar[int]
    HIDDEN_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    REGEXP_FIELD_NUMBER: _ClassVar[int]
    MIN_FIELD_NUMBER: _ClassVar[int]
    MAX_FIELD_NUMBER: _ClassVar[int]
    CHOICES_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    id: str
    key: str
    label: str
    help: str
    type: Attribute.Type
    index: int
    required: bool
    readonly: bool
    hidden: bool
    visibility: Attribute.Visibility
    regexp: str
    min: int
    max: int
    choices: _containers.RepeatedScalarFieldContainer[str]
    country: str
    constraints: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., key: _Optional[str] = ..., label: _Optional[str] = ..., help: _Optional[str] = ..., type: _Optional[_Union[Attribute.Type, str]] = ..., index: _Optional[int] = ..., required: bool = ..., readonly: bool = ..., hidden: bool = ..., visibility: _Optional[_Union[Attribute.Visibility, str]] = ..., regexp: _Optional[str] = ..., min: _Optional[int] = ..., max: _Optional[int] = ..., choices: _Optional[_Iterable[str]] = ..., country: _Optional[str] = ..., constraints: _Optional[_Iterable[str]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.ranker import activity_pb2 as _activity_pb2
from eolymp.ranker import scoreboard_pb2 as _scoreboard_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateScoreboardInput(_message.Message):
    __slots__ = ("scoreboard", "add_default_columns", "duplicate_scoreboard_id")
    SCOREBOARD_FIELD_NUMBER: _ClassVar[int]
    ADD_DEFAULT_COLUMNS_FIELD_NUMBER: _ClassVar[int]
    DUPLICATE_SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard: _scoreboard_pb2.Scoreboard
    add_default_columns: bool
    duplicate_scoreboard_id: str
    def __init__(self, scoreboard: _Optional[_Union[_scoreboard_pb2.Scoreboard, _Mapping]] = ..., add_default_columns: bool = ..., duplicate_scoreboard_id: _Optional[str] = ...) -> None: ...

class CreateScoreboardOutput(_message.Message):
    __slots__ = ("scoreboard_id",)
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ...) -> None: ...

class UpdateScoreboardInput(_message.Message):
    __slots__ = ("patch", "scoreboard_id", "scoreboard")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdateScoreboardInput.Patch]
        KEY: _ClassVar[UpdateScoreboardInput.Patch]
        NAME: _ClassVar[UpdateScoreboardInput.Patch]
        DEFAULT_SORT: _ClassVar[UpdateScoreboardInput.Patch]
        HISTORICAL: _ClassVar[UpdateScoreboardInput.Patch]
    ALL: UpdateScoreboardInput.Patch
    KEY: UpdateScoreboardInput.Patch
    NAME: UpdateScoreboardInput.Patch
    DEFAULT_SORT: UpdateScoreboardInput.Patch
    HISTORICAL: UpdateScoreboardInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdateScoreboardInput.Patch]
    scoreboard_id: str
    scoreboard: _scoreboard_pb2.Scoreboard
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateScoreboardInput.Patch, str]]] = ..., scoreboard_id: _Optional[str] = ..., scoreboard: _Optional[_Union[_scoreboard_pb2.Scoreboard, _Mapping]] = ...) -> None: ...

class UpdateScoreboardOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RebuildScoreboardInput(_message.Message):
    __slots__ = ("scoreboard_id",)
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ...) -> None: ...

class RebuildScoreboardOutput(_message.Message):
    __slots__ = ("activity_id",)
    ACTIVITY_ID_FIELD_NUMBER: _ClassVar[int]
    activity_id: str
    def __init__(self, activity_id: _Optional[str] = ...) -> None: ...

class DeleteScoreboardInput(_message.Message):
    __slots__ = ("scoreboard_id",)
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ...) -> None: ...

class DeleteScoreboardOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeScoreboardInput(_message.Message):
    __slots__ = ("scoreboard_id", "scoreboard_key")
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_KEY_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    scoreboard_key: str
    def __init__(self, scoreboard_id: _Optional[str] = ..., scoreboard_key: _Optional[str] = ...) -> None: ...

class DescribeScoreboardOutput(_message.Message):
    __slots__ = ("scoreboard",)
    SCOREBOARD_FIELD_NUMBER: _ClassVar[int]
    scoreboard: _scoreboard_pb2.Scoreboard
    def __init__(self, scoreboard: _Optional[_Union[_scoreboard_pb2.Scoreboard, _Mapping]] = ...) -> None: ...

class ListScoreboardsInput(_message.Message):
    __slots__ = ("offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("id",)
        ID_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    filters: ListScoreboardsInput.Filter
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListScoreboardsInput.Filter, _Mapping]] = ...) -> None: ...

class ListScoreboardsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_scoreboard_pb2.Scoreboard]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_scoreboard_pb2.Scoreboard, _Mapping]]] = ...) -> None: ...

class DescribeScoreboardRowInput(_message.Message):
    __slots__ = ("mode", "punctual_time", "scoreboard_id", "member_id")
    MODE_FIELD_NUMBER: _ClassVar[int]
    PUNCTUAL_TIME_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    mode: _scoreboard_pb2.Scoreboard.FetchingMode
    punctual_time: int
    scoreboard_id: str
    member_id: str
    def __init__(self, mode: _Optional[_Union[_scoreboard_pb2.Scoreboard.FetchingMode, str]] = ..., punctual_time: _Optional[int] = ..., scoreboard_id: _Optional[str] = ..., member_id: _Optional[str] = ...) -> None: ...

class DescribeScoreboardRowOutput(_message.Message):
    __slots__ = ("row", "frozen")
    ROW_FIELD_NUMBER: _ClassVar[int]
    FROZEN_FIELD_NUMBER: _ClassVar[int]
    row: _scoreboard_pb2.Scoreboard.Row
    frozen: bool
    def __init__(self, row: _Optional[_Union[_scoreboard_pb2.Scoreboard.Row, _Mapping]] = ..., frozen: bool = ...) -> None: ...

class ListScoreboardRowsInput(_message.Message):
    __slots__ = ("scoreboard_id", "mode", "punctual_time", "offset", "size", "filters", "sort", "order")
    class ExpressionColumn(_message.Message):
        __slots__ = ("key", "string", "number", "enum")
        KEY_FIELD_NUMBER: _ClassVar[int]
        STRING_FIELD_NUMBER: _ClassVar[int]
        NUMBER_FIELD_NUMBER: _ClassVar[int]
        ENUM_FIELD_NUMBER: _ClassVar[int]
        key: str
        string: _expression_pb2.ExpressionString
        number: _expression_pb2.ExpressionInt
        enum: _expression_pb2.ExpressionEnum
        def __init__(self, key: _Optional[str] = ..., string: _Optional[_Union[_expression_pb2.ExpressionString, _Mapping]] = ..., number: _Optional[_Union[_expression_pb2.ExpressionInt, _Mapping]] = ..., enum: _Optional[_Union[_expression_pb2.ExpressionEnum, _Mapping]] = ...) -> None: ...
    class Filter(_message.Message):
        __slots__ = ("member_id", "column")
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        COLUMN_FIELD_NUMBER: _ClassVar[int]
        member_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        column: _containers.RepeatedCompositeFieldContainer[ListScoreboardRowsInput.ExpressionColumn]
        def __init__(self, member_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., column: _Optional[_Iterable[_Union[ListScoreboardRowsInput.ExpressionColumn, _Mapping]]] = ...) -> None: ...
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    PUNCTUAL_TIME_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    mode: _scoreboard_pb2.Scoreboard.FetchingMode
    punctual_time: int
    offset: int
    size: int
    filters: ListScoreboardRowsInput.Filter
    sort: str
    order: _direction_pb2.Direction
    def __init__(self, scoreboard_id: _Optional[str] = ..., mode: _Optional[_Union[_scoreboard_pb2.Scoreboard.FetchingMode, str]] = ..., punctual_time: _Optional[int] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListScoreboardRowsInput.Filter, _Mapping]] = ..., sort: _Optional[str] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ...) -> None: ...

class ListScoreboardRowsOutput(_message.Message):
    __slots__ = ("total", "items", "frozen")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    FROZEN_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_scoreboard_pb2.Scoreboard.Row]
    frozen: bool
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_scoreboard_pb2.Scoreboard.Row, _Mapping]]] = ..., frozen: bool = ...) -> None: ...

class AddScoreboardColumnInput(_message.Message):
    __slots__ = ("scoreboard_id", "column")
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    column: _scoreboard_pb2.Scoreboard.Column
    def __init__(self, scoreboard_id: _Optional[str] = ..., column: _Optional[_Union[_scoreboard_pb2.Scoreboard.Column, _Mapping]] = ...) -> None: ...

class AddScoreboardColumnOutput(_message.Message):
    __slots__ = ("column_id",)
    COLUMN_ID_FIELD_NUMBER: _ClassVar[int]
    column_id: str
    def __init__(self, column_id: _Optional[str] = ...) -> None: ...

class UpdateScoreboardColumnInput(_message.Message):
    __slots__ = ("patch", "scoreboard_id", "column_id", "column")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdateScoreboardColumnInput.Patch]
        PARENT_ID: _ClassVar[UpdateScoreboardColumnInput.Patch]
        KEY: _ClassVar[UpdateScoreboardColumnInput.Patch]
        NAME: _ClassVar[UpdateScoreboardColumnInput.Patch]
        SHORT_NAME: _ClassVar[UpdateScoreboardColumnInput.Patch]
        INDEX: _ClassVar[UpdateScoreboardColumnInput.Patch]
        VISIBLE: _ClassVar[UpdateScoreboardColumnInput.Patch]
        FILTERABLE: _ClassVar[UpdateScoreboardColumnInput.Patch]
        SORTABLE: _ClassVar[UpdateScoreboardColumnInput.Patch]
    ALL: UpdateScoreboardColumnInput.Patch
    PARENT_ID: UpdateScoreboardColumnInput.Patch
    KEY: UpdateScoreboardColumnInput.Patch
    NAME: UpdateScoreboardColumnInput.Patch
    SHORT_NAME: UpdateScoreboardColumnInput.Patch
    INDEX: UpdateScoreboardColumnInput.Patch
    VISIBLE: UpdateScoreboardColumnInput.Patch
    FILTERABLE: UpdateScoreboardColumnInput.Patch
    SORTABLE: UpdateScoreboardColumnInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    COLUMN_ID_FIELD_NUMBER: _ClassVar[int]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdateScoreboardColumnInput.Patch]
    scoreboard_id: str
    column_id: str
    column: _scoreboard_pb2.Scoreboard.Column
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateScoreboardColumnInput.Patch, str]]] = ..., scoreboard_id: _Optional[str] = ..., column_id: _Optional[str] = ..., column: _Optional[_Union[_scoreboard_pb2.Scoreboard.Column, _Mapping]] = ...) -> None: ...

class UpdateScoreboardColumnOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteScoreboardColumnInput(_message.Message):
    __slots__ = ("scoreboard_id", "column_id")
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    COLUMN_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    column_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ..., column_id: _Optional[str] = ...) -> None: ...

class DeleteScoreboardColumnOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeScoreboardColumnInput(_message.Message):
    __slots__ = ("scoreboard_id", "column_id")
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    COLUMN_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    column_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ..., column_id: _Optional[str] = ...) -> None: ...

class DescribeScoreboardColumnOutput(_message.Message):
    __slots__ = ("column",)
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    column: _scoreboard_pb2.Scoreboard.Column
    def __init__(self, column: _Optional[_Union[_scoreboard_pb2.Scoreboard.Column, _Mapping]] = ...) -> None: ...

class ListScoreboardColumnsInput(_message.Message):
    __slots__ = ("scoreboard_id",)
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ...) -> None: ...

class ListScoreboardColumnsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_scoreboard_pb2.Scoreboard.Column]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_scoreboard_pb2.Scoreboard.Column, _Mapping]]] = ...) -> None: ...

class ListActivitiesInput(_message.Message):
    __slots__ = ("scoreboard_id", "offset", "size")
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    offset: int
    size: int
    def __init__(self, scoreboard_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class ListActivitiesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_activity_pb2.Activity]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_activity_pb2.Activity, _Mapping]]] = ...) -> None: ...

class ScheduleActionInput(_message.Message):
    __slots__ = ("scoreboard_id", "action")
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    action: _scoreboard_pb2.Scoreboard.Action
    def __init__(self, scoreboard_id: _Optional[str] = ..., action: _Optional[_Union[_scoreboard_pb2.Scoreboard.Action, _Mapping]] = ...) -> None: ...

class ScheduleActionOutput(_message.Message):
    __slots__ = ("action_id",)
    ACTION_ID_FIELD_NUMBER: _ClassVar[int]
    action_id: str
    def __init__(self, action_id: _Optional[str] = ...) -> None: ...

class UnscheduleActionInput(_message.Message):
    __slots__ = ("scoreboard_id", "action_id")
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    ACTION_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    action_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ..., action_id: _Optional[str] = ...) -> None: ...

class UnscheduleActionOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListScheduledActionsInput(_message.Message):
    __slots__ = ("scoreboard_id",)
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    scoreboard_id: str
    def __init__(self, scoreboard_id: _Optional[str] = ...) -> None: ...

class ListScheduledActionsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_scoreboard_pb2.Scoreboard.Action]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_scoreboard_pb2.Scoreboard.Action, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/webhook/webhook.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/webhook/webhook.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/webhook/webhook.proto\x12\x0e\x65olymp.webhook\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9e\x08\n\x07Webhook\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06secret\x18\x03 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x04 \x01(\t\x12\x10\n\x08inactive\x18\x05 \x01(\x08\x12-\n\x06\x65vents\x18\n \x03(\x0e\x32\x1d.eolymp.webhook.Webhook.Event\x12.\n\ncreated_at\x18\x1e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0flast_failure_at\x18  \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0flast_success_at\x18! \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x64\x65livery_count\x18\x14 \x01(\x05\x12\x15\n\rfailure_count\x18\x15 \x01(\x05\"\xd7\x04\n\x05\x45vent\x12\x11\n\rUNKNOWN_EVENT\x10\x00\x12\x13\n\x0fPROBLEM_CHANGED\x10\x64\x12\x1d\n\x19PROBLEM_STATEMENT_CHANGED\x10\x65\x12\x19\n\x15PROBLEM_SCORE_CHANGED\x10\x66\x12\x17\n\x12SUBMISSION_CHANGED\x10\xc8\x01\x12\x19\n\x14SUBMISSION_COMPLETED\x10\xc9\x01\x12\x13\n\x0eMEMBER_CHANGED\x10\xac\x02\x12\x12\n\rGROUP_CHANGED\x10\xde\x02\x12\x1a\n\x15\x43OURSE_MODULE_CHANGED\x10\x90\x03\x12\x1c\n\x17\x43OURSE_MATERIAL_CHANGED\x10\x91\x03\x12\x1b\n\x16\x43OURSE_STUDENT_CHANGED\x10\x92\x03\x12\x1e\n\x19\x43OURSE_ASSIGNMENT_CHANGED\x10\x93\x03\x12\x1f\n\x1a\x44ISCUSSION_MESSAGE_CHANGED\x10\xf4\x03\x12\x11\n\x0cPOST_CHANGED\x10\xd8\x04\x12\x1d\n\x18POST_TRANSLATION_CHANGED\x10\xd9\x04\x12\x13\n\x0ePOST_PUBLISHED\x10\xda\x04\x12\x13\n\x0eTICKET_CHANGED\x10\xbc\x05\x12\x19\n\x14TICKET_REPLY_CHANGED\x10\xbd\x05\x12!\n\x1c\x43ONTEST_SUBMISSION_COMPLETED\x10\xa0\x06\x12\x1a\n\x15\x43ONTEST_SCORE_CHANGED\x10\xa1\x06\x12 \n\x1b\x43ONTEST_PARTICIPANT_CHANGED\x10\xa2\x06\x12\x1f\n\x1a\x43ONTEST_PARTICIPANT_JOINED\x10\xa3\x06\"s\n\x05Patch\x12\x11\n\rPATCH_UNKNOWN\x10\x00\x12\r\n\tPATCH_ALL\x10\x01\x12\x0e\n\nPATCH_NAME\x10\x02\x12\x12\n\x0ePATCH_ENDPOINT\x10\x03\x12\x12\n\x0ePATCH_INACTIVE\x10\x04\x12\x10\n\x0cPATCH_EVENTS\x10\x05\x42\x31Z/github.com/eolymp/go-sdk/eolymp/webhook;webhookb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.webhook.webhook_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/webhook;webhook'
  _globals['_WEBHOOK']._serialized_start=82
  _globals['_WEBHOOK']._serialized_end=1136
  _globals['_WEBHOOK_EVENT']._serialized_start=420
  _globals['_WEBHOOK_EVENT']._serialized_end=1019
  _globals['_WEBHOOK_PATCH']._serialized_start=1021
  _globals['_WEBHOOK_PATCH']._serialized_end=1136
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Institution(_message.Message):
    __slots__ = ("id", "name", "acronym", "local_name", "local_acronym", "logo_url", "governance", "level", "type", "country_id", "region_id", "address", "links")
    class Governance(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_GOVERNANCE: _ClassVar[Institution.Governance]
        PUBLIC: _ClassVar[Institution.Governance]
        PRIVATE: _ClassVar[Institution.Governance]
        CHARTER: _ClassVar[Institution.Governance]
    UNKNOWN_GOVERNANCE: Institution.Governance
    PUBLIC: Institution.Governance
    PRIVATE: Institution.Governance
    CHARTER: Institution.Governance
    class Level(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_LEVEL: _ClassVar[Institution.Level]
        PRESCHOOL: _ClassVar[Institution.Level]
        PRIMARY: _ClassVar[Institution.Level]
        SECONDARY: _ClassVar[Institution.Level]
        TERTIARY: _ClassVar[Institution.Level]
    UNKNOWN_LEVEL: Institution.Level
    PRESCHOOL: Institution.Level
    PRIMARY: Institution.Level
    SECONDARY: Institution.Level
    TERTIARY: Institution.Level
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_TYPE: _ClassVar[Institution.Type]
        KINDERGARTEN: _ClassVar[Institution.Type]
        SCHOOL: _ClassVar[Institution.Type]
        LYCEUM: _ClassVar[Institution.Type]
        GYMNASIUM: _ClassVar[Institution.Type]
        COLLEGE: _ClassVar[Institution.Type]
        INSTITUTE: _ClassVar[Institution.Type]
        UNIVERSITY: _ClassVar[Institution.Type]
        ACADEMY: _ClassVar[Institution.Type]
    UNKNOWN_TYPE: Institution.Type
    KINDERGARTEN: Institution.Type
    SCHOOL: Institution.Type
    LYCEUM: Institution.Type
    GYMNASIUM: Institution.Type
    COLLEGE: Institution.Type
    INSTITUTE: Institution.Type
    UNIVERSITY: Institution.Type
    ACADEMY: Institution.Type
    class LinksEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ACRONYM_FIELD_NUMBER: _ClassVar[int]
    LOCAL_NAME_FIELD_NUMBER: _ClassVar[int]
    LOCAL_ACRONYM_FIELD_NUMBER: _ClassVar[int]
    LOGO_URL_FIELD_NUMBER: _ClassVar[int]
    GOVERNANCE_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_ID_FIELD_NUMBER: _ClassVar[int]
    REGION_ID_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    acronym: str
    local_name: str
    local_acronym: str
    logo_url: str
    governance: Institution.Governance
    level: Institution.Level
    type: Institution.Type
    country_id: str
    region_id: str
    address: str
    links: _containers.ScalarMap[str, str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., acronym: _Optional[str] = ..., local_name: _Optional[str] = ..., local_acronym: _Optional[str] = ..., logo_url: _Optional[str] = ..., governance: _Optional[_Union[Institution.Governance, str]] = ..., level: _Optional[_Union[Institution.Level, str]] = ..., type: _Optional[_Union[Institution.Type, str]] = ..., country_id: _Optional[str] = ..., region_id: _Optional[str] = ..., address: _Optional[str] = ..., links: _Optional[_Mapping[str, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/events.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/events.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.judge import participant_pb2 as eolymp_dot_judge_dot_participant__pb2
from eolymp.judge import score_pb2 as eolymp_dot_judge_dot_score__pb2
from eolymp.judge import submission_pb2 as eolymp_dot_judge_dot_submission__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/judge/events.proto\x12\x0c\x65olymp.judge\x1a\x1e\x65olymp/judge/participant.proto\x1a\x18\x65olymp/judge/score.proto\x1a\x1d\x65olymp/judge/submission.proto\"\\\n\x18SubmissionCompletedEvent\x12\x12\n\ncontest_id\x18\n \x01(\t\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Submission\"<\n\x11RebuildScoreEvent\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63tivity_id\x18\x02 \x01(\t\"w\n\x11ScoreChangedEvent\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12\x12\n\nunofficial\x18\x04 \x01(\x08\x12\"\n\x05score\x18\x03 \x01(\x0b\x32\x13.eolymp.judge.Score\"\x82\x01\n\x17ParticipantChangedEvent\x12\x12\n\ncontest_id\x18\n \x01(\t\x12)\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\x12(\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x19.eolymp.judge.Participant\"\\\n\x16ParticipantJoinedEvent\x12\x12\n\ncontest_id\x18\n \x01(\t\x12.\n\x0bparticipant\x18\x02 \x01(\x0b\x32\x19.eolymp.judge.Participant\"Q\n\x12RetestProblemEvent\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x13\n\x0b\x61\x63tivity_id\x18\x03 \x01(\tB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_SUBMISSIONCOMPLETEDEVENT']._serialized_start=132
  _globals['_SUBMISSIONCOMPLETEDEVENT']._serialized_end=224
  _globals['_REBUILDSCOREEVENT']._serialized_start=226
  _globals['_REBUILDSCOREEVENT']._serialized_end=286
  _globals['_SCORECHANGEDEVENT']._serialized_start=288
  _globals['_SCORECHANGEDEVENT']._serialized_end=407
  _globals['_PARTICIPANTCHANGEDEVENT']._serialized_start=410
  _globals['_PARTICIPANTCHANGEDEVENT']._serialized_end=540
  _globals['_PARTICIPANTJOINEDEVENT']._serialized_start=542
  _globals['_PARTICIPANTJOINEDEVENT']._serialized_end=634
  _globals['_RETESTPROBLEMEVENT']._serialized_start=636
  _globals['_RETESTPROBLEMEVENT']._serialized_end=717
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/editor_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/atlas/editor_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.runtime import runtime_pb2 as eolymp_dot_runtime_dot_runtime__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/atlas/editor_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/runtime/runtime.proto\"\x81\x02\n\x06\x45\x64itor\x12)\n\x05state\x18\x01 \x01(\x0b\x32\x1a.eolymp.atlas.Editor.State\x12.\n\x08\x66\x65\x61tures\x18\n \x03(\x0e\x32\x1c.eolymp.atlas.Editor.Feature\x12)\n\x08runtimes\x18\x0b \x03(\x0b\x32\x17.eolymp.runtime.Runtime\x1a\x41\n\x05State\x12\x0f\n\x07runtime\x18\x01 \x01(\t\x12\x13\n\x0bsource_code\x18\x02 \x01(\t\x12\x12\n\ninput_data\x18\x03 \x01(\t\".\n\x07\x46\x65\x61ture\x12\x13\n\x0fUNKNOWN_FEATURE\x10\x00\x12\x0e\n\nPRINT_CODE\x10\x01\"\x15\n\x13\x44\x65scribeEditorInput\"<\n\x14\x44\x65scribeEditorOutput\x12$\n\x06\x65\x64itor\x18\x01 \x01(\x0b\x32\x14.eolymp.atlas.Editor\"\x1a\n\x18\x44\x65scribeEditorStateInput\"\x85\x01\n\x19\x44\x65scribeEditorStateOutput\x12\x0f\n\x07runtime\x18\x01 \x01(\t\x12\x13\n\x0bsource_code\x18\x02 \x01(\t\x12\x12\n\ninput_data\x18\x03 \x01(\t\x12.\n\x08\x66\x65\x61tures\x18\n \x03(\x0e\x32\x1c.eolymp.atlas.Editor.Feature\"R\n\x16UpdateEditorStateInput\x12\x0f\n\x07runtime\x18\x01 \x01(\t\x12\x13\n\x0bsource_code\x18\x02 \x01(\t\x12\x12\n\ninput_data\x18\x03 \x01(\t\"\x19\n\x17UpdateEditorStateOutput\"<\n\x14PrintEditorCodeInput\x12\x0f\n\x07runtime\x18\x01 \x01(\t\x12\x13\n\x0bsource_code\x18\x02 \x01(\t\"\x17\n\x15PrintEditorCodeOutput2\x9a\x05\n\rEditorService\x12\x94\x01\n\x0e\x44\x65scribeEditor\x12!.eolymp.atlas.DescribeEditorInput\x1a\".eolymp.atlas.DescribeEditorOutput\";\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read\x82\xd3\xe4\x93\x02\t\x12\x07/editor\x12\xa9\x01\n\x13\x44\x65scribeEditorState\x12&.eolymp.atlas.DescribeEditorStateInput\x1a\'.eolymp.atlas.DescribeEditorStateOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read\x82\xd3\xe4\x93\x02\x0f\x12\r/editor/state\x12\xa4\x01\n\x11UpdateEditorState\x12$.eolymp.atlas.UpdateEditorStateInput\x1a%.eolymp.atlas.UpdateEditorStateOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1a\x8a\xe3\n\x16\x61tlas:submission:write\x82\xd3\xe4\x93\x02\x0f\"\r/editor/state\x12\x9e\x01\n\x0fPrintEditorCode\x12\".eolymp.atlas.PrintEditorCodeInput\x1a#.eolymp.atlas.PrintEditorCodeOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1a\x8a\xe3\n\x16\x61tlas:submission:write\x82\xd3\xe4\x93\x02\x0f\"\r/editor/printB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.editor_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_EDITORSERVICE'].methods_by_name['DescribeEditor']._loaded_options = None
  _globals['_EDITORSERVICE'].methods_by_name['DescribeEditor']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\343\n\031\212\343\n\025atlas:submission:read\202\323\344\223\002\t\022\007/editor'
  _globals['_EDITORSERVICE'].methods_by_name['DescribeEditorState']._loaded_options = None
  _globals['_EDITORSERVICE'].methods_by_name['DescribeEditorState']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\343\n\031\212\343\n\025atlas:submission:read\202\323\344\223\002\017\022\r/editor/state'
  _globals['_EDITORSERVICE'].methods_by_name['UpdateEditorState']._loaded_options = None
  _globals['_EDITORSERVICE'].methods_by_name['UpdateEditorState']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\032\212\343\n\026atlas:submission:write\202\323\344\223\002\017\"\r/editor/state'
  _globals['_EDITORSERVICE'].methods_by_name['PrintEditorCode']._loaded_options = None
  _globals['_EDITORSERVICE'].methods_by_name['PrintEditorCode']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\032\212\343\n\026atlas:submission:write\202\323\344\223\002\017\"\r/editor/print'
  _globals['_EDITOR']._serialized_start=181
  _globals['_EDITOR']._serialized_end=438
  _globals['_EDITOR_STATE']._serialized_start=325
  _globals['_EDITOR_STATE']._serialized_end=390
  _globals['_EDITOR_FEATURE']._serialized_start=392
  _globals['_EDITOR_FEATURE']._serialized_end=438
  _globals['_DESCRIBEEDITORINPUT']._serialized_start=440
  _globals['_DESCRIBEEDITORINPUT']._serialized_end=461
  _globals['_DESCRIBEEDITOROUTPUT']._serialized_start=463
  _globals['_DESCRIBEEDITOROUTPUT']._serialized_end=523
  _globals['_DESCRIBEEDITORSTATEINPUT']._serialized_start=525
  _globals['_DESCRIBEEDITORSTATEINPUT']._serialized_end=551
  _globals['_DESCRIBEEDITORSTATEOUTPUT']._serialized_start=554
  _globals['_DESCRIBEEDITORSTATEOUTPUT']._serialized_end=687
  _globals['_UPDATEEDITORSTATEINPUT']._serialized_start=689
  _globals['_UPDATEEDITORSTATEINPUT']._serialized_end=771
  _globals['_UPDATEEDITORSTATEOUTPUT']._serialized_start=773
  _globals['_UPDATEEDITORSTATEOUTPUT']._serialized_end=798
  _globals['_PRINTEDITORCODEINPUT']._serialized_start=800
  _globals['_PRINTEDITORCODEINPUT']._serialized_end=860
  _globals['_PRINTEDITORCODEOUTPUT']._serialized_start=862
  _globals['_PRINTEDITORCODEOUTPUT']._serialized_end=885
  _globals['_EDITORSERVICE']._serialized_start=888
  _globals['_EDITORSERVICE']._serialized_end=1554
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/runtime/runtime_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/runtime/runtime_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.runtime import language_pb2 as eolymp_dot_runtime_dot_language__pb2
from eolymp.runtime import runtime_pb2 as eolymp_dot_runtime_dot_runtime__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/runtime/runtime_service.proto\x12\x0e\x65olymp.runtime\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/runtime/language.proto\x1a\x1c\x65olymp/runtime/runtime.proto\x1a!eolymp/wellknown/expression.proto\",\n\x15\x44\x65scribeLanguageInput\x12\x13\n\x0blanguage_id\x18\x01 \x01(\t\"D\n\x16\x44\x65scribeLanguageOutput\x12*\n\x08language\x18\x01 \x01(\x0b\x32\x18.eolymp.runtime.Language\"\x9f\x02\n\x12ListLanguagesInput\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.runtime.ListLanguagesInput.Filter\x1a\xcc\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x34\n\ndeprecated\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x04type\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\">\n\x13ListLanguagesOutput\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.runtime.Language\"*\n\x14\x44\x65scribeRuntimeInput\x12\x12\n\nruntime_id\x18\x01 \x01(\t\"A\n\x15\x44\x65scribeRuntimeOutput\x12(\n\x07runtime\x18\x01 \x01(\x0b\x32\x17.eolymp.runtime.Runtime\"\xfc\x02\n\x11ListRuntimesInput\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.runtime.ListRuntimesInput.Filter\x1a\xab\x02\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12,\n\x04lang\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07version\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x34\n\ndeprecated\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x04type\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"<\n\x12ListRuntimesOutput\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.runtime.Runtime\"/\n\x19\x44\x65scribeCodeTemplateInput\x12\x12\n\nruntime_id\x18\x01 \x01(\t\".\n\x1a\x44\x65scribeCodeTemplateOutput\x12\x10\n\x08template\x18\x01 \x01(\t2\xe3\x06\n\x0eRuntimeService\x12\xaf\x01\n\x10\x44\x65scribeLanguage\x12%.eolymp.runtime.DescribeLanguageInput\x1a&.eolymp.runtime.DescribeLanguageOutput\"L\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x18\x8a\xe3\n\x14runtime:runtime:read\x82\xd3\xe4\x93\x02\x1a\x12\x18/languages/{language_id}\x12\x98\x01\n\rListLanguages\x12\".eolymp.runtime.ListLanguagesInput\x1a#.eolymp.runtime.ListLanguagesOutput\">\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x18\x8a\xe3\n\x14runtime:runtime:read\x82\xd3\xe4\x93\x02\x0c\x12\n/languages\x12\xa9\x01\n\x0f\x44\x65scribeRuntime\x12$.eolymp.runtime.DescribeRuntimeInput\x1a%.eolymp.runtime.DescribeRuntimeOutput\"I\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x18\x8a\xe3\n\x14runtime:runtime:read\x82\xd3\xe4\x93\x02\x17\x12\x15/runtime/{runtime_id}\x12\x93\x01\n\x0cListRuntimes\x12!.eolymp.runtime.ListRuntimesInput\x1a\".eolymp.runtime.ListRuntimesOutput\"<\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x18\x8a\xe3\n\x14runtime:runtime:read\x82\xd3\xe4\x93\x02\n\x12\x08/runtime\x12\xc1\x01\n\x14\x44\x65scribeCodeTemplate\x12).eolymp.runtime.DescribeCodeTemplateInput\x1a*.eolymp.runtime.DescribeCodeTemplateOutput\"R\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x18\x8a\xe3\n\x14runtime:runtime:read\x82\xd3\xe4\x93\x02 \x12\x1e/runtime/{runtime_id}/templateB1Z/github.com/eolymp/go-sdk/eolymp/runtime;runtimeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.runtime.runtime_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/runtime;runtime'
  _globals['_RUNTIMESERVICE'].methods_by_name['DescribeLanguage']._loaded_options = None
  _globals['_RUNTIMESERVICE'].methods_by_name['DescribeLanguage']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\343\n\030\212\343\n\024runtime:runtime:read\202\323\344\223\002\032\022\030/languages/{language_id}'
  _globals['_RUNTIMESERVICE'].methods_by_name['ListLanguages']._loaded_options = None
  _globals['_RUNTIMESERVICE'].methods_by_name['ListLanguages']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\343\n\030\212\343\n\024runtime:runtime:read\202\323\344\223\002\014\022\n/languages'
  _globals['_RUNTIMESERVICE'].methods_by_name['DescribeRuntime']._loaded_options = None
  _globals['_RUNTIMESERVICE'].methods_by_name['DescribeRuntime']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\343\n\030\212\343\n\024runtime:runtime:read\202\323\344\223\002\027\022\025/runtime/{runtime_id}'
  _globals['_RUNTIMESERVICE'].methods_by_name['ListRuntimes']._loaded_options = None
  _globals['_RUNTIMESERVICE'].methods_by_name['ListRuntimes']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\343\n\030\212\343\n\024runtime:runtime:read\202\323\344\223\002\n\022\010/runtime'
  _globals['_RUNTIMESERVICE'].methods_by_name['DescribeCodeTemplate']._loaded_options = None
  _globals['_RUNTIMESERVICE'].methods_by_name['DescribeCodeTemplate']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\343\n\030\212\343\n\024runtime:runtime:read\202\323\344\223\002 \022\036/runtime/{runtime_id}/template'
  _globals['_DESCRIBELANGUAGEINPUT']._serialized_start=251
  _globals['_DESCRIBELANGUAGEINPUT']._serialized_end=295
  _globals['_DESCRIBELANGUAGEOUTPUT']._serialized_start=297
  _globals['_DESCRIBELANGUAGEOUTPUT']._serialized_end=365
  _globals['_LISTLANGUAGESINPUT']._serialized_start=368
  _globals['_LISTLANGUAGESINPUT']._serialized_end=655
  _globals['_LISTLANGUAGESINPUT_FILTER']._serialized_start=451
  _globals['_LISTLANGUAGESINPUT_FILTER']._serialized_end=655
  _globals['_LISTLANGUAGESOUTPUT']._serialized_start=657
  _globals['_LISTLANGUAGESOUTPUT']._serialized_end=719
  _globals['_DESCRIBERUNTIMEINPUT']._serialized_start=721
  _globals['_DESCRIBERUNTIMEINPUT']._serialized_end=763
  _globals['_DESCRIBERUNTIMEOUTPUT']._serialized_start=765
  _globals['_DESCRIBERUNTIMEOUTPUT']._serialized_end=830
  _globals['_LISTRUNTIMESINPUT']._serialized_start=833
  _globals['_LISTRUNTIMESINPUT']._serialized_end=1213
  _globals['_LISTRUNTIMESINPUT_FILTER']._serialized_start=914
  _globals['_LISTRUNTIMESINPUT_FILTER']._serialized_end=1213
  _globals['_LISTRUNTIMESOUTPUT']._serialized_start=1215
  _globals['_LISTRUNTIMESOUTPUT']._serialized_end=1275
  _globals['_DESCRIBECODETEMPLATEINPUT']._serialized_start=1277
  _globals['_DESCRIBECODETEMPLATEINPUT']._serialized_end=1324
  _globals['_DESCRIBECODETEMPLATEOUTPUT']._serialized_start=1326
  _globals['_DESCRIBECODETEMPLATEOUTPUT']._serialized_end=1372
  _globals['_RUNTIMESERVICE']._serialized_start=1375
  _globals['_RUNTIMESERVICE']._serialized_end=2242
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/suggestion.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/atlas/suggestion.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/atlas/suggestion.proto\x12\x0c\x65olymp.atlas\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa5\x03\n\nSuggestion\x12\n\n\x02id\x18\x01 \x01(\t\x12/\n\x06status\x18\x02 \x01(\x0e\x32\x1f.eolymp.atlas.Suggestion.Status\x12\x0e\n\x06locale\x18\x04 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\x11\n\tmember_id\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06topics\x18\x64 \x03(\t\x12\x12\n\ndifficulty\x18\x65 \x01(\r\x12&\n\tstatement\x18\x66 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12&\n\teditorial\x18g \x01(\x0b\x32\x13.eolymp.ecm.Content\"T\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tIN_REVIEW\x10\x02\x12\x0c\n\x08\x41PPROVED\x10\x03\x12\x0c\n\x08REJECTED\x10\x04\x42-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.suggestion_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_SUGGESTION']._serialized_start=107
  _globals['_SUGGESTION']._serialized_end=528
  _globals['_SUGGESTION_STATUS']._serialized_start=444
  _globals['_SUGGESTION_STATUS']._serialized_end=528
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Stats(_message.Message):
    __slots__ = ("stdin_url", "stdout_url", "stderr_url", "wall_time_duration", "cpu_time_duration", "memory_peak", "signal", "exit_code")
    STDIN_URL_FIELD_NUMBER: _ClassVar[int]
    STDOUT_URL_FIELD_NUMBER: _ClassVar[int]
    STDERR_URL_FIELD_NUMBER: _ClassVar[int]
    WALL_TIME_DURATION_FIELD_NUMBER: _ClassVar[int]
    CPU_TIME_DURATION_FIELD_NUMBER: _ClassVar[int]
    MEMORY_PEAK_FIELD_NUMBER: _ClassVar[int]
    SIGNAL_FIELD_NUMBER: _ClassVar[int]
    EXIT_CODE_FIELD_NUMBER: _ClassVar[int]
    stdin_url: str
    stdout_url: str
    stderr_url: str
    wall_time_duration: int
    cpu_time_duration: int
    memory_peak: int
    signal: int
    exit_code: int
    def __init__(self, stdin_url: _Optional[str] = ..., stdout_url: _Optional[str] = ..., stderr_url: _Optional[str] = ..., wall_time_duration: _Optional[int] = ..., cpu_time_duration: _Optional[int] = ..., memory_peak: _Optional[int] = ..., signal: _Optional[int] = ..., exit_code: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/post_type_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/discussion/post_type_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import post_type_pb2 as eolymp_dot_discussion_dot_post__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)eolymp/discussion/post_type_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a!eolymp/discussion/post_type.proto\"k\n\x15\x44\x65scribePostTypeInput\x12\x0f\n\x07type_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\n \x01(\t\x12\x31\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32!.eolymp.discussion.PostType.Extra\"C\n\x16\x44\x65scribePostTypeOutput\x12)\n\x04type\x18\x01 \x01(\x0b\x32\x1b.eolymp.discussion.PostType\"u\n\x12ListPostTypesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06locale\x18\x14 \x01(\t\x12\x31\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32!.eolymp.discussion.PostType.Extra\"P\n\x13ListPostTypesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.eolymp.discussion.PostType\"@\n\x13\x43reatePostTypeInput\x12)\n\x04type\x18\x01 \x01(\x0b\x32\x1b.eolymp.discussion.PostType\"\'\n\x14\x43reatePostTypeOutput\x12\x0f\n\x07type_id\x18\x01 \x01(\t\"Q\n\x13UpdatePostTypeInput\x12\x0f\n\x07type_id\x18\x01 \x01(\t\x12)\n\x04type\x18\x02 \x01(\x0b\x32\x1b.eolymp.discussion.PostType\"\x16\n\x14UpdatePostTypeOutput\"&\n\x13\x44\x65letePostTypeInput\x12\x0f\n\x07type_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65letePostTypeOutput2\xc1\x06\n\x0fPostTypeService\x12\x96\x01\n\x10\x44\x65scribePostType\x12(.eolymp.discussion.DescribePostTypeInput\x1a).eolymp.discussion.DescribePostTypeOutput\"-\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x17\x12\x15/post-types/{type_id}\x12\x82\x01\n\rListPostTypes\x12%.eolymp.discussion.ListPostTypesInput\x1a&.eolymp.discussion.ListPostTypesOutput\"\"\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\r\x12\x0b/post-types\x12\xa7\x01\n\x0e\x43reatePostType\x12&.eolymp.discussion.CreatePostTypeInput\x1a\'.eolymp.discussion.CreatePostTypeOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1e\x8a\xe3\n\x1a\x64iscussion:post-type:write\x82\xd3\xe4\x93\x02\r\"\x0b/post-types\x12\xb1\x01\n\x0eUpdatePostType\x12&.eolymp.discussion.UpdatePostTypeInput\x1a\'.eolymp.discussion.UpdatePostTypeOutput\"N\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1e\x8a\xe3\n\x1a\x64iscussion:post-type:write\x82\xd3\xe4\x93\x02\x17\x1a\x15/post-types/{type_id}\x12\xb1\x01\n\x0e\x44\x65letePostType\x12&.eolymp.discussion.DeletePostTypeInput\x1a\'.eolymp.discussion.DeletePostTypeOutput\"N\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1e\x8a\xe3\n\x1a\x64iscussion:post-type:write\x82\xd3\xe4\x93\x02\x17*\x15/post-types/{type_id}B7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.post_type_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_POSTTYPESERVICE'].methods_by_name['DescribePostType']._loaded_options = None
  _globals['_POSTTYPESERVICE'].methods_by_name['DescribePostType']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\027\022\025/post-types/{type_id}'
  _globals['_POSTTYPESERVICE'].methods_by_name['ListPostTypes']._loaded_options = None
  _globals['_POSTTYPESERVICE'].methods_by_name['ListPostTypes']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\r\022\013/post-types'
  _globals['_POSTTYPESERVICE'].methods_by_name['CreatePostType']._loaded_options = None
  _globals['_POSTTYPESERVICE'].methods_by_name['CreatePostType']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\036\212\343\n\032discussion:post-type:write\202\323\344\223\002\r\"\013/post-types'
  _globals['_POSTTYPESERVICE'].methods_by_name['UpdatePostType']._loaded_options = None
  _globals['_POSTTYPESERVICE'].methods_by_name['UpdatePostType']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\036\212\343\n\032discussion:post-type:write\202\323\344\223\002\027\032\025/post-types/{type_id}'
  _globals['_POSTTYPESERVICE'].methods_by_name['DeletePostType']._loaded_options = None
  _globals['_POSTTYPESERVICE'].methods_by_name['DeletePostType']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\036\212\343\n\032discussion:post-type:write\202\323\344\223\002\027*\025/post-types/{type_id}'
  _globals['_DESCRIBEPOSTTYPEINPUT']._serialized_start=198
  _globals['_DESCRIBEPOSTTYPEINPUT']._serialized_end=305
  _globals['_DESCRIBEPOSTTYPEOUTPUT']._serialized_start=307
  _globals['_DESCRIBEPOSTTYPEOUTPUT']._serialized_end=374
  _globals['_LISTPOSTTYPESINPUT']._serialized_start=376
  _globals['_LISTPOSTTYPESINPUT']._serialized_end=493
  _globals['_LISTPOSTTYPESOUTPUT']._serialized_start=495
  _globals['_LISTPOSTTYPESOUTPUT']._serialized_end=575
  _globals['_CREATEPOSTTYPEINPUT']._serialized_start=577
  _globals['_CREATEPOSTTYPEINPUT']._serialized_end=641
  _globals['_CREATEPOSTTYPEOUTPUT']._serialized_start=643
  _globals['_CREATEPOSTTYPEOUTPUT']._serialized_end=682
  _globals['_UPDATEPOSTTYPEINPUT']._serialized_start=684
  _globals['_UPDATEPOSTTYPEINPUT']._serialized_end=765
  _globals['_UPDATEPOSTTYPEOUTPUT']._serialized_start=767
  _globals['_UPDATEPOSTTYPEOUTPUT']._serialized_end=789
  _globals['_DELETEPOSTTYPEINPUT']._serialized_start=791
  _globals['_DELETEPOSTTYPEINPUT']._serialized_end=829
  _globals['_DELETEPOSTTYPEOUTPUT']._serialized_start=831
  _globals['_DELETEPOSTTYPEOUTPUT']._serialized_end=853
  _globals['_POSTTYPESERVICE']._serialized_start=856
  _globals['_POSTTYPESERVICE']._serialized_end=1689
# @@protoc_insertion_point(module_scope)
